package com.bonus.canteen.core.alloc.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.bonus.common.log.enums.OperaType;
import com.bonus.common.security.annotation.InnerAuth;
import com.bonus.common.security.annotation.RequiresPermissionsOrInnerAuth;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.alloc.domain.AllocArea;
import com.bonus.canteen.core.alloc.service.IAllocAreaService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 区域Controller
 * 
 * @author xsheng
 * @date 2025-04-03
 */
@Api(tags = "区域接口")
@RestController
@RequestMapping("/alloc_area")
public class AllocAreaController extends BaseController {
    @Autowired
    private IAllocAreaService allocAreaService;

    /**
     * 获取区域树列表
     */
    //@RequiresPermissions("alloc:area:list")
    @GetMapping("/areaTree")
    public AjaxResult deptTree(AllocArea area) {
        try {
            return success(allocAreaService.selectAreaTreeList(area));
        } catch (Exception e) {
            logger.error(e.toString(), e);
        }
        return error("系统异常,请联系管理员");
    }

    /**
     * 查询区域列表
     */
    @ApiOperation(value = "查询区域列表")
    //@RequiresPermissions("alloc:area:list")
    @GetMapping("/list")
    public TableDataInfo list(AllocArea allocArea) {
        if (allocArea.isPagenation()) {
            startPage();
        }
        List<AllocArea> list = allocAreaService.selectAllocAreaList(allocArea);
        return getDataTable(list);
    }

    /**
     * 导出区域列表
     */
    @ApiOperation(value = "导出区域列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:area:export")
    @SysLog(title = "区域", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出区域")
    @PostMapping("/export")
    public void export(HttpServletResponse response, AllocArea allocArea) {
        List<AllocArea> list = allocAreaService.selectAllocAreaList(allocArea);
        ExcelUtil<AllocArea> util = new ExcelUtil<AllocArea>(AllocArea.class);
        util.exportExcel(response, list, "区域数据");
    }

    /**
     * 获取区域详细信息
     */
    @ApiOperation(value = "获取区域详细信息")
    //@RequiresPermissions("alloc:area:query")
    @GetMapping(value = "/{areaId}")
    public AjaxResult getInfo(@PathVariable("areaId") Long areaId) {
        return success(allocAreaService.selectAllocAreaByAreaId(areaId));
    }

    /**
     * 新增区域
     */
    @ApiOperation(value = "新增区域")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:area:add")
    @SysLog(title = "区域", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增区域")
    @PostMapping
    public AjaxResult add(@RequestBody AllocArea allocArea) {
        try {
            return toAjax(allocAreaService.insertAllocArea(allocArea));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改区域
     */
    @ApiOperation(value = "修改区域")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:area:edit")
    @SysLog(title = "区域", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改区域")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody AllocArea allocArea) {
        try {
            return toAjax(allocAreaService.updateAllocArea(allocArea));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除区域
     */
    @ApiOperation(value = "删除区域")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:area:remove")
    @SysLog(title = "区域", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除区域")
	@PostMapping("/del/{areaIds}")
    public AjaxResult remove(@PathVariable Long[] areaIds) {
        return toAjax(allocAreaService.deleteAllocAreaByAreaIds(areaIds));
    }
}
